==> coin-api-war-2.14.0-sources.jar: nl/surfnet/coin/api/saml/SAMLAuthenticationManager.java <==
/*
 * Copyright 2012 SURFnet bv, The Netherlands
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.surfnet.coin.api.saml;

import java.util.Arrays;

import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.authority.SimpleGrantedAuthority;

/**
 * SAMLAuthenticationManager.java
 *
 */
public class SAMLAuthenticationManager implements AuthenticationManager{

  /* (non-Javadoc)
   * @see org.springframework.security.authentication.AuthenticationManager#authenticate(org.springframework.security.core.Authentication)
   */
  @Override
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    final SAMLAuthenticationToken newAuthenticationToken = new SAMLAuthenticationToken(authentication.getPrincipal(),
        Arrays.asList(new SimpleGrantedAuthority("ROLE_USER")));
    newAuthenticationToken.setAuthenticated(true);
    newAuthenticationToken.setDetails(authentication.getDetails());
    return newAuthenticationToken;
  }

}

==> coin-api-war-4.0.0-sources.jar: nl/surfnet/coin/api/saml/SAMLAuthenticationManager.java <==
/*
 * Copyright 2012 SURFnet bv, The Netherlands
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.surfnet.coin.api.saml;

import java.util.Arrays;

import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.authority.SimpleGrantedAuthority;

/**
 * SAMLAuthenticationManager.java
 *
 */
public class SAMLAuthenticationManager implements AuthenticationManager{

  /* (non-Javadoc)
   * @see org.springframework.security.authentication.AuthenticationManager#authenticate(org.springframework.security.core.Authentication)
   */
  @Override
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    final SAMLAuthenticationToken newAuthenticationToken = new SAMLAuthenticationToken(authentication.getPrincipal(), authentication.getAuthorities());
    newAuthenticationToken.setAuthenticated(true);
    newAuthenticationToken.setDetails(authentication.getDetails());
    return newAuthenticationToken;
  }

}
